@@ -1,19 +1,12 @@
 package Dancer::Plugin::Cache::CHI;
-BEGIN {
-  $Dancer::Plugin::Cache::CHI::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $Dancer::Plugin::Cache::CHI::VERSION = '1.4.0';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Dancer plugin to cache response content (and anything else)
-
+$Dancer::Plugin::Cache::CHI::VERSION = '1.5.0';
 use strict;
 use warnings;
 no warnings qw/ uninitialized /;
 
-use Dancer 1.1904 ':syntax';
-
-my $dancer_version = int Dancer->VERSION;
+use Dancer 1.32 ':syntax';
 
 use Carp;
 use CHI;
@@ -22,17 +15,9 @@ use Dancer::Plugin;
 
 use Moo;
 
-if ( $dancer_version < 2 ) {
-    require Dancer::Hook;
-    require Dancer::Factory::Hook;
-    require Dancer::Response;
-    require Dancer::SharedData;
-}
-else {
-    with 'Dancer::Plugin';
-
-    register_hook 'before_create_cache';
-}
+use Dancer::Factory::Hook;
+use Dancer::Response;
+use Dancer::SharedData;
 
 
 my %cache;     
@@ -58,7 +43,6 @@ hook after => sub {
 };
 
 register cache => sub {
-    shift if $dancer_version >= 2;
     return  $cache{$_[0]//''} ||= _create_cache( @_ );
 };
 
@@ -68,12 +52,7 @@ sub _create_cache {
     my $namespace = shift;
     my $args = shift || {};
 
-    if ( $dancer_version < 2 ) {
-        Dancer::Factory::Hook->execute_hooks( 'before_create_cache' );
-    }
-    else {
-        execute_hook 'before_create_cache';
-    }
+    Dancer::Factory::Hook->execute_hooks( 'before_create_cache' );
 
     my %setting = %{ plugin_setting() };
 
@@ -91,12 +70,21 @@ sub _create_cache {
 
 
 
+sub should_skip_cache {
+    return unless $honor_no_cache;
+
+    my $req =  Dancer::SharedData->request;
+
+    no warnings 'uninitialized';
+
+    return scalar grep { 
+        $req->header($_) eq 'no-cache'
+    } qw/ Cache-Control Pragma /;
+}
+
 register check_page_cache => sub {
-    shift if $dancer_version >= 2;
-
-    my $hook = sub {
-        my $dsl = shift if $dancer_version >= 2;
 
+    hook before => sub {
         # Instead halt() now we use a more correct method - setting of a
         # response to Dancer::Response object for a more correct returning of
         # some HTTP headers (X-Powered-By, Server)
@@ -104,60 +92,27 @@ register check_page_cache => sub {
         my $cached = cache()->get( $cache_page_key_generator->() )
             or return;
 
-        if ( $honor_no_cache ) {
-            $DB::single = 1;
+        return if should_skip_cache();
 
-            my $req =  $dancer_version >=2  
-                    ? $dsl->request
-                    : Dancer::SharedData->request
-                    ;
-
-            return if grep { 
-                # eval is there to protect from a regression in Dancer 1.31
-                # where headers can be undef
-                eval { $req->header($_) eq 'no-cache' }
-            } qw/ Cache-Control Pragma /;
-        }
-
-        if ( $dancer_version < 2 ) {
-            Dancer::SharedData->response(
-                Dancer::Response->new(
-                    ref $cached eq 'HASH'
-                    ?
-                    (
-                        status       => $cached->{status},
-                        headers      => $cached->{headers},
-                        content      => $cached->{content}
-                    )
-                    :
-                    ( content => $cached )
+        Dancer::SharedData->response(
+            Dancer::Response->new(
+                ref $cached eq 'HASH'
+                ?
+                (
+                    status       => $cached->{status},
+                    headers      => $cached->{headers},
+                    content      => $cached->{content}
                 )
-            );
-        } else {
-            $dsl->response(
-                Dancer::Core::Response->new(
-                    is_halted => 1,
-                    ref $cached eq 'HASH'
-                    ?
-                    (
-                        status       => $cached->{status},
-                        headers      => $cached->{headers},
-                        content      => $cached->{content}
-                    )
-                    :
-                    ( content => $cached )
-                )
-            );
-        }
+                :
+                ( content => $cached )
+            )
+        );
     };
 
-    hook before => $hook;
 };
 
 
 register cache_page => sub {
-    shift if $dancer_version >= 2;
-
     my ( $content, @args ) = @_;
 
     $cache_page = \@args;
@@ -168,41 +123,39 @@ register cache_page => sub {
 
 
 register cache_page_key => sub {
-    shift if $dancer_version >= 2;
     return $cache_page_key_generator->();
 };
 
 
 register cache_page_key_generator => sub {
-    shift if $dancer_version >= 2;
     $cache_page_key_generator = shift;
 };
 
 
 for my $method ( qw/ set get remove clear compute / ) {
     register 'cache_'.$method => sub {
-        shift if $dancer_version >= 2;
         return cache()->$method( @_ );
     }
 }
 
-Dancer::Factory::Hook->instance->install_hooks(qw/ before_create_cache /)
-    if $dancer_version < 2;
+Dancer::Factory::Hook->instance->install_hooks(qw/ before_create_cache /);
 
 
-register_plugin for_versions => [1,2];
+register_plugin;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dancer::Plugin::Cache::CHI - Dancer plugin to cache response content (and anything else)
 
 =head1 VERSION
 
-version 1.4.0
+version 1.5.0
 
 =head1 SYNOPSIS
 
@@ -362,13 +315,15 @@ L<CHI>
 
 L<Dancer::Plugin::Memcached> - plugin that heavily inspired this one.
 
+L<Dancer2::Plugin::Cache::CHI> - Dancer2 incarnation of this plugin.
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Yanick Champoux.
+This software is copyright (c) 2018, 2013, 2012, 2011 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
